
# Data Reading
- Reading the data based on user's request.
  >Done, using pandas_datareader

# Data Analysing and Visulizing
- Compute fluctuation for the time period/each day, find the max/min 
fluctuation.
  >Done
- Plot the daily fluctuation. 
  >Done. Matplotlib version. Changed to poorly version
- Plot the price for given stocks and given date range.
  >Done. Plotly version.
- Candle plot.
  >Done. Plotly version.
# Prediction with ML model(s)
 - TBATS model to do prediction, prediction interval.
   > Done
 - update method that can update the model daily.
   > Done. Can update until the given date.
 - test how many profit we can get by running this model.
   > Done. Build invest and evaluate method in evaluation submodule.
 - Plot for predicted vs real value.
   > Done. The graph method in evaluation submodule.
# Unittest
 - For visualization submodule
   > Done.
 - For model submodule
   > Done.
 - For evaluation submodule
   > Done.
# Environment issue
 - Create environment.yml
   > Done.
 - Create GitHub workflow
   > Done. Changed to pylint and unittest
 - Upload to Pypi
   > Done.

